@@ -1,14 +1,14 @@
 package Complete::Module;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete;
+use Complete::Setting;
 use List::MoreUtils qw(uniq);
 
 our %SPEC;
@@ -128,10 +128,10 @@ sub complete_module {
     #$log->tracef('[compmod] Entering complete_module(), word=<%s>', $word);
     #$log->tracef('[compmod] args=%s', \%args);
 
-    my $ci          = $args{ci} // $Complete::OPT_CI;
-    my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
-    my $dig_leaf    = $args{dig_leaf} // $Complete::OPT_DIG_LEAF;
+    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
+    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
+    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
+    my $dig_leaf    = $args{dig_leaf} // $Complete::Setting::OPT_DIG_LEAF;
     my $ns_prefix = $args{ns_prefix} // '';
     $ns_prefix =~ s/(::)+\z//;
 
@@ -225,7 +225,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.18 of Complete::Module (from Perl distribution Complete-Module), released on 2015-09-03.
+This document describes version 0.19 of Complete::Module (from Perl distribution Complete-Module), released on 2015-09-09.
 
 =head1 SYNOPSIS
 
